monks/list_style_type
The list-style-type CSS property sets the marker (such as a disc, character, or custom counter style) of a list item element.
Values
pub const revert_layer: #(String, String)
The list-style-type CSS property sets the marker (such as a disc, character, or custom counter style) of a list item element.
pub const revert_layer: #(String, String)