monks/text_decoration_color
The text-decoration-color CSS property sets the color of decorations added to text by {{ cssxref(“text-decoration-line”) }}.
The color applies to decorations, such as underlines, overlines, strikethroughs, and wavy lines like those used to mark misspellings, in the scope of the property’s value.
Values
pub fn raw(value: String) -> #(String, String)
Enter a raw string value for text-decoration-color
pub const revert_layer: #(String, String)