monks/list_style_type

The list-style-type CSS property sets the marker (such as a disc, character, or custom counter style) of a list item element.

Values

pub const inherit: #(String, String)
pub const initial: #(String, String)
pub const none: #(String, String)
  • : No item marker is shown.
pub fn raw(value: String) -> #(String, String)

Enter a raw string value for list-style-type

pub const revert: #(String, String)
pub const revert_layer: #(String, String)
pub const unset: #(String, String)
pub fn var(variable: String) -> #(String, String)

Enter a variable name to be used for list-style-type. It will be wrapped in var() and have -- prepended.

Search Document